==> docrepo-0.8.7.tar.gz: docrepo-0.8.7/docrepotek/templates/readme.py <==
readme_template = """
[![Build Status](https://travis-ci.com/{1}/{0}.svg?branch=master)](https://travis-ci.com/{1}/{0})
[![Build status](https://ci.appveyor.com/api/projects/status/yvvmq5hyf7hj743a/branch/master?svg=true)](https://ci.appveyor.com/project/{1}/{0}/branch/master)
[![Documentation Status](https://readthedocs.org/projects/{0}/badge/?version=latest)](https://{0}.readthedocs.io/en/latest/?badge=latest)
[![License: GPLv3](https://img.shields.io/badge/License-GPLV2-green.svg)](https://opensource.org/licenses/GPLV2)
[![Organization](https://img.shields.io/badge/Org-TralahTek-blue.svg)](https://github.com/TralahTek)
[![Views](http://hits.dwyl.io/{1}/{0}.svg)](http://dwyl.io/{1}/{0})
[![PRs Welcome](https://img.shields.io/badge/PRs-Welcome-brightgreen.svg?style=flat-square)](https://github.com/{1}/{0}/pull/)
[![GitHub pull-requests](https://img.shields.io/badge/Issues-pr-red.svg?style=flat-square)](https://github.com/{1}/{0}/pull/)
[![Language](https://img.shields.io/badge/Language-{2}-{3}.svg)](https://github.com/TralahM)
<img title="Watching" src="https://img.shields.io/github/watchers/{1}/{0}?label=Watchers&color=blue&style=flat-square">
<img title="Stars" src="https://img.shields.io/github/stars/{1}/{0}?color=red&style=flat-square">
<img title="Forks" src="https://img.shields.io/github/forks/{1}/{0}?color=green&style=flat-square">

# {0}.


[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-black.svg?style=for-the-badge&logo=github)](https://github.com/TralahTek)
[![{1}](https://img.shields.io/badge/Engineer-{1}-blue.svg?style=for-the-badge&logo=github)](https://github.com/{1})
[![{1}](https://img.shields.io/badge/Maintainer-{1}-green.svg?style=for-the-badge&logo=github)](https://github.com/{1})

# Documentation

[![Documentation](https://img.shields.io/badge/Docs-{0}-blue.svg?style=for-the-badge)](https://github.com/TralahM/{0})

# How to Install
```bash
# In terminal do:
```

## Building from Source for Developers

```console
$ git clone https://github.com/{1}/{0}.git
$ cd {0}
```

# Contributing
[See the Contributing File](CONTRIBUTING.rst)


[See the Pull Request File](PULL_REQUEST_TEMPLATE.md)


# Support

# LICENCE

[Read the license here](LICENSE)


# Self-Promotion

[![](https://img.shields.io/badge/Github-{1}-green?style=for-the-badge&logo=github)](https://github.com/{1})
[![](https://img.shields.io/badge/Twitter-%40tralahtek-red?style=for-the-badge&logo=twitter)](https://twitter.com/{1})
[![TralahM](https://img.shields.io/badge/Kaggle-TralahM-purple.svg?style=for-the-badge&logo=kaggle)](https://kaggle.com/TralahM)
[![TralahM](https://img.shields.io/badge/LinkedIn-TralahM-red.svg?style=for-the-badge&logo=linkedin)](https://linkedin.com/in/TralahM)


[![Blog](https://img.shields.io/badge/Blog-tralahm.tralahtek.com-blue.svg?style=for-the-badge&logo=rss)](https://tralahm.tralahtek.com)

[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-cyan.svg?style=for-the-badge)](https://org.tralahtek.com)


"""

==> docrepo-0.8.8.tar.gz: docrepo-0.8.8/docrepotek/templates/readme.py <==
readme_template = """
[![Build Status](https://travis-ci.com/{1}/{0}.svg?branch=master)](https://travis-ci.com/{1}/{0})
[![Build status](https://ci.appveyor.com/api/projects/status/yvvmq5hyf7hj743a/branch/master?svg=true)](https://ci.appveyor.com/project/{1}/{0}/branch/master)
[![Documentation Status](https://readthedocs.org/projects/{0}/badge/?version=latest)](https://{0}.readthedocs.io/en/latest/?badge=latest)
[![License: GPLv3](https://img.shields.io/badge/License-GPLV2-green.svg)](https://opensource.org/licenses/GPLV2)
[![Organization](https://img.shields.io/badge/Org-TralahTek-blue.svg)](https://github.com/TralahTek)
[![Views](http://hits.dwyl.io/{1}/{0}.svg)](http://dwyl.io/{1}/{0})
[![PRs Welcome](https://img.shields.io/badge/PRs-Welcome-brightgreen.svg?style=flat-square)](https://github.com/{1}/{0}/pull/)
[![GitHub pull-requests](https://img.shields.io/badge/Issues-pr-red.svg?style=flat-square)](https://github.com/{1}/{0}/pull/)
[![Language](https://img.shields.io/badge/Language-{2}-{3}.svg)](https://github.com/TralahM)
<img title="Watching" src="https://img.shields.io/github/watchers/{1}/{0}?label=Watchers&color=blue&style=flat-square">
<img title="Stars" src="https://img.shields.io/github/stars/{1}/{0}?color=red&style=flat-square">
<img title="Forks" src="https://img.shields.io/github/forks/{1}/{0}?color=green&style=flat-square">
<script src="https://liberapay.com/TralahM/widgets/button.js"></script>
<noscript><a href="https://liberapay.com/TralahM/donate"><img alt="Donate using Liberapay" src="https://liberapay.com/assets/widgets/donate.svg"></a></noscript>

# {0}.


[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-black.svg?style=for-the-badge&logo=github)](https://github.com/TralahTek)
[![{1}](https://img.shields.io/badge/Engineer-{1}-blue.svg?style=for-the-badge&logo=github)](https://github.com/{1})
[![{1}](https://img.shields.io/badge/Maintainer-{1}-green.svg?style=for-the-badge&logo=github)](https://github.com/{1})

# Documentation

[![Documentation](https://img.shields.io/badge/Docs-{0}-blue.svg?style=for-the-badge)](https://github.com/TralahM/{0})

# Installation
```console
# In terminal do:
$
```

## Building from Source for Developers

```console
$ git clone https://github.com/{1}/{0}.git
$ cd {0}
```

# Contributing
[See the Contributing File](CONTRIBUTING.rst)


[See the Pull Request File](PULL_REQUEST_TEMPLATE.md)


# Support

# LICENCE

[Read the license here](LICENSE)


# Self-Promotion

[![](https://img.shields.io/badge/Github-{1}-green?style=for-the-badge&logo=github)](https://github.com/{1})
[![](https://img.shields.io/badge/Twitter-%40tralahtek-blue?style=for-the-badge&logo=twitter)](https://twitter.com/{1})
[![TralahM](https://img.shields.io/badge/Kaggle-TralahM-purple.svg?style=for-the-badge&logo=kaggle)](https://kaggle.com/TralahM)
[![TralahM](https://img.shields.io/badge/LinkedIn-TralahM-white.svg?style=for-the-badge&logo=linkedin)](https://linkedin.com/in/TralahM)


[![Blog](https://img.shields.io/badge/Blog-tralahm.tralahtek.com-blue.svg?style=for-the-badge&logo=rss)](https://tralahm.tralahtek.com)

[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-cyan.svg?style=for-the-badge)](https://org.tralahtek.com)


"""
